@@ -3,7 +3,12 @@ from math import isfinite
 from soops.base import output, run_command
 
 def format_float(val, prec, replace_dot=True):
-    fmt = '{{:.{}e}}'.format(prec)
+    if isinstance(prec, int):
+        fmt = '{{:.{}e}}'.format(prec)
+
+    else:
+        fmt = '{{:{}}}'.format(prec)
+
     aux = fmt.format(val)
     if replace_dot:
         return aux.replace('.', ':') # Make LaTeX happy.
@@ -16,11 +21,16 @@ def format_float_latex(val, prec):
         return '0'
 
     elif isfinite(val):
-        fmt = '{{:.{}e}}'.format(prec)
-        sval = fmt.format(val)
-        iexp = list(map(float, sval.split('e')))
-        iexp[1] = int(iexp[1])
-        return r'${} \cdot 10^{{{}}}$'.format(*iexp)
+        if isinstance(prec, int):
+            fmt = '{{:.{}e}}'.format(prec)
+            sval = fmt.format(val)
+            iexp = list(map(float, sval.split('e')))
+            iexp[1] = int(iexp[1])
+            return r'${} \cdot 10^{{{}}}$'.format(*iexp)
+
+        else:
+            aux = r'{{:{}}}'.format(prec).format(val).replace(' ', '\enspace ')
+            return r'${}$'.format(aux)
 
     else:
         return str(val)
